@@ -9,9 +9,20 @@ from dataclasses import dataclass
 from typing import TYPE_CHECKING
 
 from simulation.game_logic.map_updaters import PickupUpdater
+from simulation.interactables.interactable import _Interactable
+from simulation.interactables.pickups import (
+    YellowOrbArtefact,
+    ChestArtefact,
+    KeyArtefact,
+    PhoneArtefact,
+    KeyboardArtefact,
+    CoinsArtefact,
+)
 from .avatar_state_serializers import (
     worksheet1_avatar_state_serializer,
     worksheet2_avatar_state_serializer,
+    worksheet3_avatar_state_serializer,
+    worksheet4_avatar_state_serializer,
 )
 
 if TYPE_CHECKING:
@@ -19,9 +30,7 @@ if TYPE_CHECKING:
     from simulation.avatar.avatar_wrapper import AvatarWrapper
     from simulation.game_logic.map_updaters import _MapUpdater
 
-    AvatarStateSerializer = NewType(
-        "AvatarStateSerializer", Callable[[AvatarWrapper], Dict]
-    )
+    AvatarStateSerializer = NewType("AvatarStateSerializer", Callable[[AvatarWrapper], Dict])
 
 
 @dataclass
@@ -37,23 +46,34 @@ worksheets = {
     1: WorksheetData(
         worksheet_id=1,
         era="future",
-        map_updaters=[PickupUpdater],
+        map_updaters=[PickupUpdater(pickup_types=[YellowOrbArtefact])],
         number_of_obstacle_textures=1,
         avatar_state_serializer=worksheet1_avatar_state_serializer,
     ),
     2: WorksheetData(
         worksheet_id=2,
         era="future",
-        map_updaters=[PickupUpdater],
+        map_updaters=[PickupUpdater(pickup_types=[YellowOrbArtefact])],
         number_of_obstacle_textures=1,
         avatar_state_serializer=worksheet2_avatar_state_serializer,
     ),
+    3: WorksheetData(
+        worksheet_id=3,
+        era="ancient",
+        map_updaters=[PickupUpdater(pickup_types=[ChestArtefact, KeyArtefact])],
+        number_of_obstacle_textures=1,
+        avatar_state_serializer=worksheet3_avatar_state_serializer,
+    ),
+    4: WorksheetData(
+        worksheet_id=4,
+        era="modern",
+        map_updaters=[PickupUpdater(pickup_types=[PhoneArtefact, KeyboardArtefact, CoinsArtefact])],
+        number_of_obstacle_textures=1,
+        avatar_state_serializer=worksheet4_avatar_state_serializer,
+    ),
 }
 
 
 def get_worksheet_data() -> WorksheetData:
     worksheet_id = int(os.environ.get("worksheet_id", 1))
     return worksheets.get(worksheet_id, worksheets[1])
-
-
-WORKSHEET = get_worksheet_data()
